@@ -14,6 +14,9 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with python-iam.  If not, see <https://www.gnu.org/licenses/>.
+"""The :mod:`iam.ext.django` package integrates the Python IAM framework
+with Django.
+"""
 
 
 default_app_config = 'iam.ext.django.apps.IAMConfig'
